"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.invoke = void 0;
process.env.FORCE_COLOR = "0";
const nanolru_1 = __importDefault(require("nanolru"));
const path_1 = __importDefault(require("path"));
const prettier_1 = __importDefault(require("prettier"));
const prettier_2 = require("prettier");
const configCache = new nanolru_1.default({ max: 20, maxAge: 60000 });
async function resolveConfig(cwd, filepath) {
    let v = configCache.get(cwd);
    if (!v) {
        v = await prettier_1.default.resolveConfig(filepath, {
            editorconfig: true,
            useCache: false,
        });
        if (v) {
            configCache.set(cwd, v);
        }
    }
    return {
        ...v,
        filepath,
    };
}
function resolveFile(cwd, fileName) {
    if (path_1.default.isAbsolute(fileName)) {
        return [fileName, fileName];
    }
    return [cwd, path_1.default.join(cwd, fileName)];
}
async function run(cwd, args, text) {
    const fileName = args[0] === "--no-color" ? args[1] : args[0];
    const [cacheKey, fullPath] = resolveFile(cwd, fileName);
    const options = await resolveConfig(cacheKey, fullPath);
    return prettier_2.format(text, options);
}
function invoke(cwd, args, text, _mtime, cb) {
    run(cwd, args, text)
        .then((resp) => void cb(undefined, resp))
        .catch((error) => void cb(error));
}
exports.invoke = invoke;
